@@ -8,7 +8,9 @@
   fi
 
   echo "[encoding: UTF-8]" > po/POTFILES.in \
-  && ls -1 data/gajim.desktop.in.in data/glade/*.glade \
+  && for p in `ls data/gui/*.ui`; do echo "[type: gettext/glade]$p" >> \
+  po/POTFILES.in; done \
+  && ls -1 data/gajim.desktop.in.in \
   src/*py src/common/*py src/common/zeroconf/*.py | grep -v ipython_view.py >> \
   po/POTFILES.in || exit 1
   if test -z `which pkg-config 2>/dev/null`;then
